@@ -18,11 +18,11 @@ describe 'ironic::db::inspector_sync' do
 
   context 'on a RedHat osfamily' do
     let :facts do
-      {
+      @default_facts.merge({
         :osfamily                 => 'RedHat',
         :operatingsystemrelease   => '7.0',
         :concat_basedir => '/var/lib/puppet/concat'
-      }
+      })
     end
 
     it_configures 'inspector-dbsync'
@@ -30,12 +30,12 @@ describe 'ironic::db::inspector_sync' do
 
   context 'on a Debian osfamily' do
     let :facts do
-      {
+      @default_facts.merge({
         :operatingsystemrelease => '7.8',
         :operatingsystem        => 'Debian',
         :osfamily               => 'Debian',
         :concat_basedir => '/var/lib/puppet/concat'
-      }
+      })
     end
 
     it_configures 'inspector-dbsync'
