@@ -24,7 +24,7 @@ describe 'ironic::client' do
 
   context 'on Debian platforms' do
     let :facts do
-      { :osfamily => 'Debian' }
+       @default_facts.merge({ :osfamily => 'Debian' })
     end
 
     it { is_expected.to contain_class('ironic::client') }
@@ -32,7 +32,7 @@ describe 'ironic::client' do
 
   context 'on RedHat platforms' do
     let :facts do
-      { :osfamily => 'RedHat' }
+       @default_facts.merge({ :osfamily => 'RedHat' })
     end
 
     it { is_expected.to contain_class('ironic::client') }
