@@ -84,25 +84,6 @@ describe 'ironic::keystone::auth' do
     ) }
   end
 
-  describe 'with deprecated endpoint parameters' do
-    let :params do
-      { :password         => 'ironic_password',
-        :public_protocol  => 'https',
-        :public_port      => '80',
-        :public_address   => '10.10.10.10',
-        :port             => '81',
-        :internal_address => '10.10.10.11',
-        :admin_address    => '10.10.10.12' }
-    end
-
-    it { is_expected.to contain_keystone_endpoint('RegionOne/ironic::baremetal').with(
-      :ensure       => 'present',
-      :public_url   => "https://10.10.10.10:80",
-      :internal_url => "http://10.10.10.11:81",
-      :admin_url    => "http://10.10.10.12:81"
-    ) }
-  end
-
   describe 'when overriding auth name' do
     let :params do
       { :password => 'foo',
@@ -111,8 +92,8 @@ describe 'ironic::keystone::auth' do
 
     it { is_expected.to contain_keystone_user('ironicy') }
     it { is_expected.to contain_keystone_user_role('ironicy@services') }
-    it { is_expected.to contain_keystone_service('ironicy::baremetal') }
-    it { is_expected.to contain_keystone_endpoint('RegionOne/ironicy::baremetal') }
+    it { is_expected.to contain_keystone_service('ironic::baremetal') }
+    it { is_expected.to contain_keystone_endpoint('RegionOne/ironic::baremetal') }
   end
 
   describe 'when overriding service name' do
