@@ -3,11 +3,11 @@ require 'spec_helper'
 describe 'ironic::wsgi::apache' do
 
   let :global_facts do
-    {
+    OSDefaults.get_facts({
       :processorcount => 42,
       :concat_basedir => '/var/lib/puppet/concat',
       :fqdn           => 'some.host.tld'
-    }
+    })
   end
 
   shared_examples_for 'apache serving ironic with mod_wsgi' do
@@ -49,7 +49,7 @@ describe 'ironic::wsgi::apache' do
         'wsgi_script_aliases'         => { '/' => "#{platform_parameters[:wsgi_script_path]}/app" },
         'require'                     => 'File[ironic_wsgi]'
       )}
-      it { is_expected.to contain_file("#{platform_parameters[:httpd_ports_file]}") }
+      it { is_expected.to contain_concat("#{platform_parameters[:httpd_ports_file]}") }
     end
 
     describe 'when overriding parameters using different ports' do
@@ -77,7 +77,7 @@ describe 'ironic::wsgi::apache' do
         'require'                     => 'File[ironic_wsgi]'
       )}
 
-      it { is_expected.to contain_file("#{platform_parameters[:httpd_ports_file]}") }
+      it { is_expected.to contain_concat("#{platform_parameters[:httpd_ports_file]}") }
     end
   end
 
